﻿/*******************************************************************************
File        : Program.cs
Description : Example of full error checking
--------------------------------------------------------------------------------
Functions:
--------------------------------------------------------------------------------
History:
2011/05/17 TPR Created
*******************************************************************************/
using System;
using Wiker.WIDatabase;
using System.Text;

namespace ErrorChecking
{
   class Program
   {
      /*******************************************************************************
      Function    : Main()
      Description : Example of full error checking
      Parameters  : string[] args - 
      Returns     : void
      --------------------------------------------------------------------------------
      History:
      2011/05/17 TPR Created
      *******************************************************************************/
      static void Main(string[] args)
      {
         WIDatabase WIDB; 
         CDatabaseInfo DBInfo;
         string Str, ColumnDataStr;
         int ColumnDataInt;
         StringBuilder StrB;

         /* Create DatabaseInfo object with login info  */
         DBInfo = new CDatabaseInfo();
         DBInfo.DatabaseType = eDatabaseType.SQLite;
         DBInfo.Location =  "\\WIDatabase\\Samples";
         DBInfo.DBName = "SQLite.db3";         
         DBInfo.Password = "";
         DBInfo.Port = 0;
         DBInfo.Username = "";

         /* Create the object */
         WIDB = new WIDatabase(DBInfo);
         
         /* Configure Global Settings */

         /* Change to wait only 30 seconds for connection time out */
         SETTINGS.ConnectionTimeOut = 30;

         /* Wait 30 seconds for Query to time out */
         SETTINGS.QueryTimeOut = 30;

         /* Only Trim beginning of data */
         SETTINGS.Trimming = eTrim.Start;

         /* Do not make any changes to SQL Variable */
         SETTINGS.PrepareSQLVariable = false;

         /* Call function DatabaseFailureCallBack() upon Database failure */
         SETTINGS.DatabaseFailureCallBack = DatabaseFailureCallBack;

         /* Call function DebugLogCallBack() to Log debug messages */
         SETTINGS.DebugLogCallBack = DebugLogCallBack;


         /* Check the last error */
         if (WIDB.LastError != eDBErrorCodes.None)
            {
            Str = string.Format("Error occured while creating WIDB:\n{0}\n{1}",WIDB.LastError,WIDB.LastErrorMessage);
            Console.WriteLine(Str);
            return;
            }

         /* Check to see if DB exists */
         if (!WIDB.Database.Exists())
            {
            Str = string.Format("Database '{0}' does not exist. Please create it." , DBInfo.DBName);
            Console.WriteLine(Str);
            return;
            }
         
         /* Check the last error  */
         if (WIDB.LastError != eDBErrorCodes.None)
            {
            Str = string.Format("Error occured while executing the select:\n{0}\n{1}",WIDB.LastError,WIDB.LastErrorMessage);
            Console.WriteLine(Str);
            return;
            }

         /* Make Sure the table exists before selecting */
         if (!WIDB.Table.Exists("tblAddress"))
            {
            Str = string.Format("The table 'tblAddress' in database '{0}' does not exist.", DBInfo.DBName);
            Console.WriteLine(Str);
            return;
            }

         /* Check the last error  */
         if (WIDB.LastError != eDBErrorCodes.None)
            {
            Str = string.Format("Error occured while executing the select:\n{0}\n{1}",WIDB.LastError,WIDB.LastErrorMessage);
            Console.WriteLine(Str);
            return;
            }

         /*
            See the Select example for more information
         */

         WIDB.Search.Clear();
         WIDB.Search.Column( "AddressID");
         WIDB.Search.Column("Address1");
         WIDB.Search.Column("Address2");
         WIDB.Search.Column("City");
         WIDB.Search.Column("State");
         WIDB.Search.Column("ZipCode");
         WIDB.Search.Table("tblAddress");

         /* check if execution succeeded */
         if (!WIDB.Search.Execute())
            {
            Str = string.Format("Error occured while executing the select:\n{0}\n{1}",WIDB.LastError,WIDB.LastErrorMessage);
            Console.WriteLine(Str);
            return;
            }

         /* Check the last error  */
         if (WIDB.LastError != eDBErrorCodes.None)
            {
            Str = string.Format("Error occured while executing the select:\n{0}\n{1}",WIDB.LastError,WIDB.LastErrorMessage);
            Console.WriteLine(Str);
            return;
            }

         Console.WriteLine("| AddressID | Address1 | Address2 | City | State | Zip |");

         /* read the results of the query */
         while (WIDB.Search.Read())
            {
            /* Check the last error  */
            if (WIDB.LastError != eDBErrorCodes.None)
               {
               Str = string.Format("Error occured while executing the select:\n{0}\n{1}",WIDB.LastError,WIDB.LastErrorMessage);
               Console.WriteLine(Str);
               return;
               }

            StrB = new StringBuilder();
            
            if (!WIDB.Search.Get("AddressID",out ColumnDataInt))
               ColumnDataInt = -1;

            StrB.AppendFormat("| {0} ",ColumnDataInt);

            if (!WIDB.Search.Get("Address1",out ColumnDataStr))
               ColumnDataStr = "ERROR GETTING COLUMN";
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            if (!WIDB.Search.Get("Address2",out ColumnDataStr))
               ColumnDataStr = "ERROR GETTING COLUMN";
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            if (!WIDB.Search.Get("City",out ColumnDataStr))
               ColumnDataStr = "ERROR GETTING COLUMN";
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            if (!WIDB.Search.Get("State",out ColumnDataStr))
               ColumnDataStr = "ERROR GETTING COLUMN";
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            if (!WIDB.Search.Get("ZipCode",out ColumnDataStr))
               ColumnDataStr = "ERROR GETTING COLUMN";
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            Console.WriteLine(StrB.ToString());
            }

         Console.WriteLine();
         Console.WriteLine(string.Format("Statement sent to the Database:\n{0}",WIDB.SQLStatement));

         /* Good practice is to close the DB when finished */
         WIDB.Close();
      }
      /*******************************************************************************
      Function    : DatabaseFailureCallBack()
      Description : 
      Parameters  : eDBErrorCodes errorCode - 
      Returns     : bool
      --------------------------------------------------------------------------------
      History:
      2011/07/13 TPR Created
      *******************************************************************************/
      private static bool DatabaseFailureCallBack(eDBErrorCodes errorCode)
      {
         Console.WriteLine(string.Format("DBFailureCallback {0}", errorCode.ToString()));
         return(true);
      }
      /*******************************************************************************
      Function    : DebugLogCallBack()
      Description : 
      Parameters  : string message - 
                  : Exception ex - 
      Returns     : void
      --------------------------------------------------------------------------------
      History:
      2011/07/13 TPR Created
      *******************************************************************************/
      private static void DebugLogCallBack(string message, Exception ex)
      {
         Console.WriteLine(string.Format("{0}\n{1}", message, ex.Message));
      }
   }/* End Class */
}/* End NameSpace */
