﻿/*******************************************************************************
File        : Company.cs
Description : 
--------------------------------------------------------------------------------
Functions:
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
using System;
using System.Windows.Forms;
using System.Drawing;
using Wiker.WIDatabase;
using System.Collections.ObjectModel;

namespace WIDatabaseSample
{
/*******************************************************************************
Class        : MainForm
Description  : 
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
public partial class MainForm
{
/*******************************************************************************
Function    : CompanyNeedsSaved()
Description : 
Parameters  : bool needsSaved - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
void CompanyNeedsSaved(bool needsSaved)
{
pictureCompanySave.Visible = needsSaved;
buttonCompanyUpdate.Enabled = needsSaved;
buttonCompanyNew.Enabled = needsSaved;
}
/*******************************************************************************
Function    : textCompany_TextChanged()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
private void textCompany_TextChanged(object sender, EventArgs e)
{
Control Sender;

Sender = sender as Control;

if (Sender == null || !Sender.Focused)
   return;

CompanyNeedsSaved(true);
}
/*******************************************************************************
Function    : checkCompanyActive_CheckStateChanged()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
private void checkCompanyActive_CheckStateChanged(object sender, EventArgs e)
{
if (!checkCompanyActive.Focused)
   return;

CompanyNeedsSaved(true);
}
/*******************************************************************************
Function    : comboCompanyCompany_SelectionChangeCommitted()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
private void comboCompanyCompany_SelectionChangeCommitted(object sender, EventArgs e)
{
stComboItem ComboItem;
stCompany Company;

EnableCompany(true);

ComboItem = comboCompanyCompany.SelectedItem as stComboItem;

if (ComboItem == null)
   return;

Company = ComboItem.Tag as stCompany;
if (Company == null)
   return;

if (Company.Name.Equals(NEW_COMPANY))
   {
   buttonCompanyDelete.Enabled = false;
   ClearCompany();
   EnableCompany(true);
   textCompanyName.Focus();
   return;
   }

LoadCompany(Company);

textCompanyName.Focus();

buttonCompanyDelete.Enabled = true;
}
/*******************************************************************************
Function    : LoadCompany()
Description : 
Parameters  : stCompany company - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/11 WLM Created
*******************************************************************************/
bool LoadCompany(stCompany company)
{
bool Result;

if (UseSELECT)
   Result = SearchCompanySELECT(company);

else
   Result = SearchCompanyWI(company);

if (!Result)
   return(false);

DisplayCompany(company);

return(true);
}
/*******************************************************************************
Function    : SearchCompanyWI()
Description : 
Parameters  : stCompany company - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/11 WLM Created
*******************************************************************************/
bool SearchCompanyWI(stCompany company)
{
WIDatabase WIDB;
Collection<CCondition> Conditions;
string Str;

if (company == null || company.CompanyID < 1)
   return(false);

/* Create Connection And Open Database */
WIDB = new WIDatabase(GetDBInfo());

if (WIDB.LastError != eDBErrorCodes.None)
   {
   Str = string.Format("Failed to open database\n{0}\nLastError = {1}", GetDBName(WIDB.DatabaseType),
      WIDB.LastError.ToString());
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/

WIDB.Search.Clear();
WIDB.Search.Column("tblCompany", "CompanyID");
WIDB.Search.Column("tblCompany", "AddressID");
WIDB.Search.Column("Name");
WIDB.Search.Column("LogoID");
WIDB.Search.Column("WebSite");
WIDB.Search.Column("Active");
WIDB.Search.Column("Address1");
WIDB.Search.Column("Address2");
WIDB.Search.Column("City");
WIDB.Search.Column("State");
WIDB.Search.Column("ZipCode");
WIDB.Search.Column("ImageData");
WIDB.Search.Column("P1", "Number", "CompanyPhone");
WIDB.Search.Column("P2", "Number", "CompanyFax");

WIDB.Search.Table("tblCompany");
WIDB.Search.Condition("tblCompany", "CompanyID", eOperator.Equal, company.CompanyID);

WIDB.Search.Join("tblAddress", "AddressID", eOperator.Equal, "tblCompany", "AddressID", eJoinType.Left);
WIDB.Search.Join("tblImage", "ImageID", eOperator.Equal, "tblCompany", "LogoID", eJoinType.Left);

Conditions = new Collection<CCondition>();
Conditions.Add(new CCondition("P1", "CompanyID", eOperator.Equal, "tblCompany", "CompanyID"));
Conditions.Add(new CCondition(eLogic.AND));
Conditions.Add(new CCondition("P1", "Type", eOperator.Equal, (int)ePhoneType.Work));
WIDB.Search.Join("tblPhone", "P1", Conditions, eJoinType.Left);

Conditions = new Collection<CCondition>();
Conditions.Add(new CCondition("P2", "CompanyID", eOperator.Equal, "tblCompany", "CompanyID"));
Conditions.Add(new CCondition(eLogic.AND));
Conditions.Add(new CCondition("P2", "Type", eOperator.Equal, (int)ePhoneType.Fax));
WIDB.Search.Join("tblPhone", "P2", Conditions, eJoinType.Left);

/*----------------------------------------------------------------------------*/

if (!WIDB.Search.Execute()) /* Build/Check Select Statement */
   {
   Str = string.Format("Failed to search tblCompany\nLastError = {0}\n{1}", WIDB.LastError,
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

if (!WIDB.Search.Read()) /* Loop Through Results */
   {
   WIDB.Close();
   return(false);
   }

/*----------------------------------------------------------------------------*/

WIDB.Search.Clear();
WIDB.Search.Get("CompanyID", out company.CompanyID);
WIDB.Search.Get("AddressID", out company.Address.AddressID);
WIDB.Search.Get("Name", out company.Name);
WIDB.Search.Get("LogoID", out company.LogoID);
WIDB.Search.Get("WebSite", out company.WebSite);
WIDB.Search.Get("Active", out company.Active);
WIDB.Search.Get("Address1", out company.Address.Address1);
WIDB.Search.Get("Address2", out company.Address.Address2);
WIDB.Search.Get("City", out company.Address.City);
WIDB.Search.Get("State", out company.Address.State);
WIDB.Search.Get("ZipCode", out company.Address.ZipCode);
WIDB.Search.Get("ImageData", out company.LogoImage);
WIDB.Search.Get("CompanyPhone", out company.Phone);
WIDB.Search.Get("CompanyFax", out company.Fax);

WIDB.Close();

return(true);
}
/*******************************************************************************
Function    : DisplayCompany()
Description : 
Parameters  : stCompany company - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/14 WLM Created
*******************************************************************************/
void DisplayCompany(stCompany company)
{
textCompanyName.Text = company.Name;
textCompanyAddress1.Text = company.Address.Address1;
textCompanyAddress2.Text = company.Address.Address2;
textCompanyCity.Text = company.Address.City;
textCompanyState.Text = company.Address.State;
textCompanyZip.Text = company.Address.ZipCode;
textCompanyWebSite.Text = company.WebSite;
textCompanyPhone.Text = company.Phone;
textCompanyFax.Text = company.Fax;

checkCompanyActive.Checked = company.Active;
pictureCompanyLogo.Image = company.LogoImage;
}
/*******************************************************************************
Function    : ClearCompany()
Description : 
Parameters  : None
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
void ClearCompany()
{
textCompanyName.Text = "";
textCompanyAddress1.Text = "";
textCompanyAddress2.Text = "";
textCompanyCity.Text = "";
textCompanyState.Text = "";
textCompanyZip.Text = "";
textCompanyWebSite.Text = "";
textCompanyPhone.Text = "";
textCompanyFax.Text = "";

checkCompanyActive.Checked = false;
pictureCompanyLogo.Image = null;

EnableCompany(false);
CompanyNeedsSaved(false);
buttonCompanyDelete.Enabled = false;
}
/*******************************************************************************
Function    : EnableCompany()
Description : 
Parameters  : bool enabled - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
void EnableCompany(bool enabled)
{
textCompanyName.Enabled = enabled;
textCompanyAddress1.Enabled = enabled;
textCompanyAddress2.Enabled = enabled;
textCompanyCity.Enabled = enabled;
textCompanyState.Enabled = enabled;
textCompanyZip.Enabled = enabled;
textCompanyWebSite.Enabled = enabled;
textCompanyPhone.Enabled = enabled;
textCompanyFax.Enabled = enabled;

checkCompanyActive.Enabled = enabled;
pictureCompanyLogo.Enabled = enabled;
}
/*******************************************************************************
Function    : GetCompanyInfo()
Description : 
Parameters  : stCompany company - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/11 WLM Created
*******************************************************************************/
bool GetCompanyInfo(stCompany company)
{
company.Name = textCompanyName.Text.Trim();

if (string.IsNullOrEmpty(company.Name))
   {
   MessageBox.Show("Company name must be entered");
   textCompanyName.Focus();
   return(false);
   }

company.Address.Address1 = textCompanyAddress1.Text.Trim();
company.Address.Address2 = textCompanyAddress2.Text.Trim();
company.Address.City = textCompanyCity.Text.Trim();
company.Address.State = textCompanyState.Text.Trim();
company.Address.ZipCode = textCompanyZip.Text.Trim();

company.WebSite = textCompanyWebSite.Text.Trim();
company.Active = checkCompanyActive.Checked;

company.Phone = textCompanyPhone.Text.Trim();
company.Fax = textCompanyFax.Text.Trim();

company.LogoImage = pictureCompanyLogo.Image;

return(true);
}
/*******************************************************************************
Function    : buttonCompanyUpdate_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
private void buttonCompanyUpdate_Click(object sender, EventArgs e)
{
stComboItem ComboItem;
stCompany Company;
bool Result;

ComboItem = comboCompanyCompany.SelectedItem as stComboItem;
if (ComboItem == null)
   return;

Company = ComboItem.Tag as stCompany;
if (Company == null)
   return;

if (!GetCompanyInfo(Company))
   return;


if (UseSELECT)
   Result = UpdateCompanySELECT(Company);

else
   Result = UpdateCompanyWI(Company);

if (Result)
   ComboItem.Text = Company.Name;

CompanyNeedsSaved(!Result);

if (!Result)
   return;

comboCompanyCompany.Items.Remove(ComboItem);
comboCompanyCompany.Items.Add(ComboItem);
comboCompanyCompany.SelectedItem = ComboItem;
}
/*******************************************************************************
Function    : UpdateCompanyWI()
Description : 
Parameters  : stCompany company - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/11 WLM Created
*******************************************************************************/
bool UpdateCompanyWI(stCompany company)
{
string Str;
WIDatabase WIDB;

/* Create Connection And Open Database */
WIDB = new WIDatabase(GetDBInfo());

if (WIDB.LastError != eDBErrorCodes.None)
   {
   Str = string.Format("Failed to open database\n{0}\nLastError = {1}", GetDBName(WIDB.DatabaseType),
      WIDB.LastError.ToString());
   MessageBox.Show(Str);
   return(false);
   }

/* Update Company Address */
if (!UpdateAddressWI(WIDB, company.Address))
   {
   WIDB.Close();
   Str = string.Format("Failed to Update Address\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/

/* Update Company Logo If Exists */
if (company.LogoImage != null)
   {
   if (company.LogoID > 0) /* Update Existing Image */
      {
      if (!UpdateImageWI(WIDB, company.LogoImage, company.LogoID))
         {
         WIDB.Close();
         Str = string.Format("Failed to Update Logo Image\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
            WIDB.LastErrorMessage);
         MessageBox.Show(Str);
         return(false);
         }
      }

   else
      {  /* New Image */
      if (!SaveImageWI(WIDB, company.LogoImage, out company.LogoID))
         {
         WIDB.Close();
         Str = string.Format("Failed to Save Logo Image\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
            WIDB.LastErrorMessage);
         MessageBox.Show(Str);
         return(false);
         }
      }
   }

else
if(company.LogoID > 0) /* Delete Existing Image */
   {
   if (!DeleteImageWI(WIDB, company.LogoID))
      {
      WIDB.Close();
      Str = string.Format("Failed to Delete Logo Image\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
         WIDB.LastErrorMessage);
      MessageBox.Show(Str);
      return(false);
      }
   }

/*----------------------------------------------------------------------------*/

/* Update Company Infomation */
if (!UpdateCompanyWI(WIDB, company))
   {
   WIDB.Close();
   Str = string.Format("Failed to Update Company\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Update Company Work Phone */
if (!UpdatePhoneWI(WIDB, company.CompanyID, 0, ePhoneType.Work, company.Phone))
   {
   WIDB.Close();
   Str = string.Format("Failed to Update Work Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Update Company Fax Phone */
if (!UpdatePhoneWI(WIDB, company.CompanyID, 0, ePhoneType.Fax, company.Fax))
   {
   WIDB.Close();
   Str = string.Format("Failed to Update Fax Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

WIDB.Close();

return(true);
}
/*******************************************************************************
Function    : buttonCompanyNew_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/05/06 WLM Created
*******************************************************************************/
private void buttonCompanyNew_Click(object sender, EventArgs e)
{
stComboItem ComboItem;
stCompany Company;
bool Result;

Company = new stCompany();

if (!GetCompanyInfo(Company))
   return;

if (UseSELECT)
   Result = NewCompanySELECT(Company);

else
   Result = NewCompanyWI(Company);

CompanyNeedsSaved(!Result);

if (!Result)
   return;

ComboItem = new stComboItem(Company.Name, Company);
comboCompanyCompany.Items.Add(ComboItem);
comboPersonCompany.Items.Add(ComboItem);

comboCompanyCompany.SelectedItem = ComboItem;
}
/*******************************************************************************
Function    : NewCompanyWI()
Description : 
Parameters  : stCompany company - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
bool NewCompanyWI(stCompany company)
{
string Str;
WIDatabase WIDB;

/* Create Connection And Open Database */
WIDB = new WIDatabase(GetDBInfo());

if (WIDB.LastError != eDBErrorCodes.None)
   {
   Str = string.Format("Failed to open database\n{0}\nLastError = {1}", GetDBName(WIDB.DatabaseType),
      WIDB.LastError.ToString());
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/

/* Save Company Address */
if (!SaveAddressWI(WIDB, company.Address))
   {
   WIDB.Close();
   Str = string.Format("Failed to Save Address\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Save Company Logo If Exists */
if (company.LogoImage != null)
   {
   if (!SaveImageWI(WIDB, company.LogoImage, out company.LogoID))
      {
      WIDB.Close();
      Str = string.Format("Failed to Save Logo Image\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
         WIDB.LastErrorMessage);
      MessageBox.Show(Str);
      return(false);
      }
   }

/* Save Company Infomation */
if (!SaveCompanyWI(WIDB, company))
   {
   WIDB.Close();
   Str = string.Format("Failed to Save Company\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Save Company Work Phone */
if (!SavePhoneWI(WIDB, company.CompanyID, 0, ePhoneType.Work, company.Phone))
   {
   WIDB.Close();
   Str = string.Format("Failed to Save Work Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Save Company Fax Phone */
if (!SavePhoneWI(WIDB, company.CompanyID, 0, ePhoneType.Fax, company.Fax))
   {
   WIDB.Close();
   Str = string.Format("Failed to Save Fax Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

WIDB.Close();

return(true);
}
/*******************************************************************************
Function    : SaveAddressWI()
Description : 
Parameters  : WIDatabase db - 
            : stAddress address - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/04/13 WLM Created
*******************************************************************************/
bool SaveAddressWI(WIDatabase db, stAddress address)
{
db.Insert.Clear();
db.Insert.Table("tblAddress");

db.Insert.Column("Address1", address.Address1);
db.Insert.Column("Address2", address.Address2);
db.Insert.Column("City", address.City);
db.Insert.Column("State", address.State);
db.Insert.Column("ZipCode", address.ZipCode);

if (!db.Insert.Execute(out address.AddressID))
   return(false);

return(true);
}
/*******************************************************************************
Function    : SaveCompanyWI()
Description : 
Parameters  : WIDatabase db - 
            : stCompany company - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/04/13 WLM Created
*******************************************************************************/
bool SaveCompanyWI(WIDatabase db, stCompany company)
{
db.Insert.Clear();
db.Insert.Table("tblCompany");

db.Insert.Column("Name", company.Name);
db.Insert.Column("WebSite", company.WebSite);
db.Insert.Column("Active", company.Active);
db.Insert.Column("AddressID", company.Address.AddressID);
db.Insert.Column("LogoID", company.LogoID);

if (!db.Insert.Execute(out company.CompanyID))
   return(false);

return(true);
}
/*******************************************************************************
Function    : SavePhoneWI()
Description : 
Parameters  : WIDatabase db - 
            : int companyID - 
            : int personID - 
            : ePhoneType phoneType - 
            : string phoneNumber - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool SavePhoneWI(WIDatabase db, int companyID, int personID, ePhoneType phoneType, string phoneNumber)
{
db.Insert.Clear();
db.Insert.Table("tblPhone");

if (companyID > 0)
   db.Insert.Column("CompanyID", companyID);

else
if (personID > 0)
   db.Insert.Column("PersonID", personID);

else
   return(false);

db.Insert.Column("Type", phoneType);
db.Insert.Column("Number", phoneNumber);

if (!db.Insert.Execute())
   return(false);

return(true);
}
/*******************************************************************************
Function    : SaveImageWI()
Description : 
Parameters  : WIDatabase db - 
            : Image image - 
            : out int id - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool SaveImageWI(WIDatabase db, Image image, out int id)
{
db.Insert.Clear();
db.Insert.Table("tblImage");

db.Insert.Column("ImageData", image);

if (!db.Insert.Execute(out id))
   return(false);

return(true);
}
/*******************************************************************************
Function    : buttonCompanyDelete_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
private void buttonCompanyDelete_Click(object sender, EventArgs e)
{
stComboItem ComboItem;
stCompany Company;
bool Result;
string Str;

ComboItem = comboCompanyCompany.SelectedItem as stComboItem;
if (ComboItem == null)
   return;

Company = ComboItem.Tag as stCompany;
if (Company == null)
   return;

Str = string.Format("Delete Company {0}", Company.Name);
if (MessageBox.Show(Str, "", MessageBoxButtons.YesNo) == DialogResult.No)
   return;

if (UseSELECT)
   Result = DeleteCompanySELECT(Company);

else
   Result = DeleteCompanyWI(Company);

CompanyNeedsSaved(!Result);

if (!Result)
   return;

ClearCompany();

comboCompanyCompany.Items.Remove(ComboItem);
comboCompanyCompany.SelectedIndex = -1;
}
/*******************************************************************************
Function    : DeleteCompanyWI()
Description : 
Parameters  : stCompany company - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/12 WLM Created
*******************************************************************************/
bool DeleteCompanyWI(stCompany company)
{
string Str;
WIDatabase WIDB;

/* Create Connection And Open Database */
WIDB = new WIDatabase(GetDBInfo());

if (WIDB.LastError != eDBErrorCodes.None)
   {
   Str = string.Format("Failed to open database\n{0}\nLastError = {1}", GetDBName(WIDB.DatabaseType),
      WIDB.LastError.ToString());
   MessageBox.Show(Str);
   return(false);
   }

if (company.Address.AddressID > 0)
   {
   if (!DeleteAddressWI(WIDB, company.Address))
      {
      WIDB.Close();
      Str = string.Format("Failed to Delete Address\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
         WIDB.LastErrorMessage);
      MessageBox.Show(Str);
      return(false);
      }
   }

if (company.LogoID > 0)
   {
   if (!DeleteImageWI(WIDB, company.LogoID))
      {
      WIDB.Close();
      Str = string.Format("Failed to Delete Logo\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
         WIDB.LastErrorMessage);
      MessageBox.Show(Str);
      return(false);
      }
   }

if (!DeletePhoneWI(WIDB, company.CompanyID, 0, ePhoneType.Work))
   {
   WIDB.Close();
   Str = string.Format("Failed to Delete Work Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

if (!DeletePhoneWI(WIDB, company.CompanyID, 0, ePhoneType.Fax))
   {
   WIDB.Close();
   Str = string.Format("Failed to Delete Fax\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

if (company.CompanyID > 0)
   {
   if (!DeleteCompanyWI(WIDB, company.CompanyID))
      {
      WIDB.Close();
      Str = string.Format("Failed to Delete Company\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
         WIDB.LastErrorMessage);
      MessageBox.Show(Str);
      return(false);
      }
   }

WIDB.Close();

return(true);
}
/*******************************************************************************
Function    : DeleteAddressWI()
Description : 
Parameters  : WIDatabase db - 
            : stAddress address - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/12 WLM Created
*******************************************************************************/
bool DeleteAddressWI(WIDatabase db, stAddress address)
{
bool Result;

if (address == null || address.AddressID < 1)
   return(false);

db.Delete.Clear();
db.Delete.Table("tblAddress");
db.Delete.Condition("AddressID", eOperator.Equal, address.AddressID);

Result = db.Delete.Execute();

return(Result);
}
/*******************************************************************************
Function    : DeleteCompanyWI()
Description : 
Parameters  : WIDatabase db - 
            : int companyID - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool DeleteCompanyWI(WIDatabase db, int companyID)
{
bool Result;

if (companyID < 1)
   return(false);

db.Delete.Clear();
db.Delete.Table("tblCompany");
db.Delete.Condition("CompanyID", eOperator.Equal, companyID);

Result = db.Delete.Execute();

return(Result);
}
/*******************************************************************************
Function    : DeletePhoneWI()
Description : 
Parameters  : WIDatabase db - 
            : int companyID - 
            : int personID - 
            : ePhoneType phoneType - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool DeletePhoneWI(WIDatabase db, int companyID, int personID, ePhoneType phoneType)
{
bool Result;

if (companyID < 1 && personID < 1)
   return(false);

db.Delete.Clear();
db.Delete.Table("tblPhone");
db.Delete.Condition("Type", eOperator.Equal, (int)phoneType);
db.Delete.Condition(eLogic.AND);

if (companyID > 0)
   db.Delete.Condition("CompanyID", eOperator.Equal, companyID);

else
if (personID > 0)
   db.Delete.Condition("PersonID", eOperator.Equal, personID);

else
   return(false);

Result = db.Delete.Execute();

return(true);
}
/*******************************************************************************
Function    : DeleteImageWI()
Description : 
Parameters  : WIDatabase db - 
            : int imageID - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool DeleteImageWI(WIDatabase db, int imageID)
{
bool Result;

if (imageID < 1)
   return(false);

db.Delete.Clear();
db.Delete.Table("tblImage");

db.Delete.Condition("ImageID", eOperator.Equal, imageID);

Result = db.Delete.Execute();

return(Result);
}
/*******************************************************************************
Function    : tsCompanySelect_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
private void tsCompanySelect_Click(object sender, EventArgs e)
{
OpenFileDialog OpenDialog;
string Str;

try
{
OpenDialog = new OpenFileDialog();

OpenDialog.Filter
   = "Select Image (*.gif;*.jpg;*.jpe;*.jpeg;*.png;*.bmp;)|*.gif;*.jpg;*.jpe;*.jpeg;*.png;*.bmp;";
OpenDialog.RestoreDirectory = true;

if (OpenDialog.ShowDialog() != DialogResult.OK)
   {
   OpenDialog.Dispose();
   return;
   }

pictureCompanyLogo.Image = Image.FromFile(OpenDialog.FileName);
OpenDialog.Dispose();

CompanyNeedsSaved(true);
}

catch (Exception ex)
   {
   Str = string.Format("Failed to load image\n{0}", ex.Message);
   MessageBox.Show(Str);
   }
}
/*******************************************************************************
Function    : tsCompanyClear_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
private void tsCompanyClear_Click(object sender, EventArgs e)
{
pictureCompanyLogo.Image = null;
CompanyNeedsSaved(true);
}
/*******************************************************************************
Function    : tsCompanyCopy_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
private void tsCompanyCopy_Click(object sender, EventArgs e)
{
CutPasteImage = pictureCompanyLogo.Image;
}
/*******************************************************************************
Function    : tsCompanyPaste_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
private void tsCompanyPaste_Click(object sender, EventArgs e)
{
pictureCompanyLogo.Image = CutPasteImage;
CompanyNeedsSaved(true);
}
/*******************************************************************************
Function    : LoadCompanyCombos()
Description : 
Parameters  : None
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/04/14 WLM Created
*******************************************************************************/
bool LoadCompanyCombos()
{
bool Result;
stComboItem ComboItem;

comboCompanyCompany.Items.Clear();          /* Clear Company ComboBoxes */
comboPersonCompany.Items.Clear();

/* Add <New>'s to ComboBoxes */
ComboItem = new stComboItem(NEW_COMPANY, new stCompany(NEW_COMPANY));
comboCompanyCompany.Items.Add(ComboItem);
comboPersonCompany.Items.Add(ComboItem);

if (UseSELECT)
   Result = LoadCompanyNamesSELECT();

else
   Result = LoadCompanyNamesWI();

return(Result);
}
/*******************************************************************************
Function    : UpdateAddressWI()
Description : 
Parameters  : WIDatabase db - 
            : stAddress address - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/17 WLM Created
*******************************************************************************/
bool UpdateAddressWI(WIDatabase db, stAddress address)
{
bool Result;

if (address == null || address.AddressID < 1)
   return(false);

db.Update.Clear();
db.Update.Table("tblAddress");

db.Update.Column("Address1", address.Address1);
db.Update.Column("Address2", address.Address2);
db.Update.Column("City", address.City);
db.Update.Column("State", address.State);
db.Update.Column("ZipCode", address.ZipCode);

db.Update.Condition("AddressID", eOperator.Equal, address.AddressID);

Result = db.Update.Execute();

return(Result);
}
/*******************************************************************************
Function    : UpdateCompanyWI()
Description : 
Parameters  : WIDatabase db - 
            : stCompany company - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/11 WLM Created
*******************************************************************************/
bool UpdateCompanyWI(WIDatabase db, stCompany company)
{
bool Result;

if (company == null || company.CompanyID < 1)
   return(false);

db.Update.Clear();
db.Update.Table("tblCompany");

db.Update.Column("Name", company.Name);
db.Update.Column("WebSite", company.WebSite);
db.Update.Column("Active", company.Active);
db.Update.Column("AddressID", company.Address.AddressID);
db.Update.Column("LogoID", company.LogoID);

db.Update.Condition("CompanyID", eOperator.Equal, company.CompanyID);

Result = db.Update.Execute();

return(Result);
}
/*******************************************************************************
Function    : UpdatePhoneWI()
Description : 
Parameters  : WIDatabase db - 
            : int companyID - 
            : int personID - 
            : ePhoneType phoneType - 
            : string phoneNumber - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool UpdatePhoneWI(WIDatabase db, int companyID, int personID, ePhoneType phoneType, string phoneNumber)
{
bool Result;

db.Update.Clear();
db.Update.Table("tblPhone");

db.Update.Column("Number", phoneNumber);
db.Update.Condition("Type", eOperator.Equal, (int)phoneType);
db.Update.Condition(eLogic.AND);

if (companyID > 0)
   db.Update.Condition("CompanyID", eOperator.Equal, companyID);

else
if (personID > 0)
   db.Update.Condition("PersonID", eOperator.Equal, personID);

else
   return(false);

Result = db.Update.Execute();

return(true);
}
/*******************************************************************************
Function    : UpdateImageWI()
Description : 
Parameters  : WIDatabase db - 
            : Image image - 
            : int imageID - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool UpdateImageWI(WIDatabase db, Image image, int imageID)
{
bool Result;

if (image == null || imageID < 1)
   return(false);

db.Update.Clear();
db.Update.Table("tblImage");

db.Update.Column("ImageData", image);
db.Update.Condition("ImageID", eOperator.Equal, imageID);

Result = db.Update.Execute();

return(true);
}
/*******************************************************************************
Function    : LoadCompanyNamesWI()
Description : 
Parameters  : None
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/04/14 WLM Created
*******************************************************************************/
bool LoadCompanyNamesWI()
{
WIDatabase WIDB;
string Str;
stCompany Company;
stComboItem ComboItem;

/* Create Connection And Open Database */
WIDB = new WIDatabase(GetDBInfo());

if (WIDB.LastError != eDBErrorCodes.None)
   {
   Str = string.Format("Failed to open database\n{0}\nLastError = {1}", GetDBName(WIDB.DatabaseType),
      WIDB.LastError.ToString());
   MessageBox.Show(Str);
   return(false);
   }

/* Build Select Request */
WIDB.Search.Column("CompanyID");
WIDB.Search.Column("Name");
WIDB.Search.Table("tblCompany");
WIDB.Search.Sort("Name", eSort.Ascending);

/*----------------------------------------------------------------------------*/

if (!WIDB.Search.Execute()) /* Build/Check Select Statement */
   {
   Str = string.Format("Failed to search tblCompany\nLastError = {0}\n{1}", WIDB.LastError,
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

while (WIDB.Search.Read()) /* Loop Through Results */
   {
   Company = new stCompany();
   WIDB.Search.Get("Name", out Company.Name);
   WIDB.Search.Get("CompanyID", out Company.CompanyID);

   /* Add Company Names To ComboBoxes */
   ComboItem = new stComboItem(Company.Name, Company);
   comboCompanyCompany.Items.Add(ComboItem);
   comboPersonCompany.Items.Add(ComboItem);
   }

WIDB.Close();

return(true);
}
} /* End Of Class MainForm */
} /* End Of NameSpace WIDatabaseSample */