﻿/*******************************************************************************
File        : Person.cs
Description : 
--------------------------------------------------------------------------------
Functions:
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
using System;
using System.Windows.Forms;
using System.Drawing;

namespace WIDatabaseSample
{
/*******************************************************************************
Class        : MainForm
Description  : 
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
public partial class MainForm
{
/*******************************************************************************
Function    : PersonNeedsSaved()
Description : 
Parameters  : bool needsSaved - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
void PersonNeedsSaved(bool needsSaved)
{
picturePersonSave.Visible = needsSaved;
buttonPersonUpdate.Enabled = needsSaved;
buttonPersonNew.Enabled = needsSaved;
}
/*******************************************************************************
Function    : textPerson_TextChanged()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
private void textPerson_TextChanged(object sender, EventArgs e)
{
Control Sender;

Sender = sender as Control;

if (Sender == null || !Sender.Focused)
   return;

PersonNeedsSaved(true);
}
/*******************************************************************************
Function    : checkPersonActive_CheckStateChanged()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
private void checkPersonActive_CheckStateChanged(object sender, EventArgs e)
{
if (!checkPersonActive.Focused)
   return;

PersonNeedsSaved(true);
}
/*******************************************************************************
Function    : comboPersonPerson_SelectionChangeCommitted()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/05/12 WLM Created
*******************************************************************************/
private void comboPersonPerson_SelectionChangeCommitted(object sender, EventArgs e)
{
stComboItem ComboItem;
stPerson Person;

EnablePerson(true);

ComboItem = comboPersonPerson.SelectedItem as stComboItem;

if (ComboItem == null)
   return;

Person = ComboItem.Tag as stPerson;
if (Person == null)
   return;

if (Person.Name.Equals(NEW_PERSON))
   {
   buttonPersonDelete.Enabled = false;
   ClearPerson();
   EnablePerson(true);
   textPersonName.Focus();
   return;
   }

LoadPerson(Person);

textPersonName.Focus();

buttonPersonDelete.Enabled = true;
}
/*******************************************************************************
Function    : LoadPerson()
Description : 
Parameters  : stPerson person - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/12 WLM Created
*******************************************************************************/
bool LoadPerson(stPerson person)
{
bool Result;

if (UseSELECT)
   Result = SearchPersonSELECT(person);

else
   Result = SearchPersonWI(person);

if (!Result)
   return(false);

DisplayPerson(person);

return(true);
}
/*******************************************************************************
Function    : DisplayPerson()
Description : 
Parameters  : stPerson person - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/05/12 WLM Created
*******************************************************************************/
void DisplayPerson(stPerson person)
{
textPersonName.Text = person.Name;

textPersonAddress1.Text = person.Address.Address1;
textPersonAddress2.Text = person.Address.Address2;
textPersonCity.Text = person.Address.City;
textPersonState.Text = person.Address.State;
textPersonZip.Text = person.Address.ZipCode;

checkPersonActive.Checked = person.Active;
picturePersonPhoto.Image = person.PhotoImage;

textPersonPhoneHome.Text = person.PhoneHome;
textPersonPhoneWork.Text = person.PhoneWork;
textPersonPhoneCell.Text = person.PhoneCell;
textPersonPhoneFax.Text = person.PhoneFax;
textPersonPhoneOther.Text = person.PhoneOther;

comboPersonCompany.SelectedIndex = comboPersonCompany.FindStringExact(person.Company.Name);
}
/*******************************************************************************
Function    : ClearPerson()
Description : 
Parameters  : None
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
void ClearPerson()
{
textPersonName.Text = "";
textPersonAddress1.Text = "";
textPersonAddress2.Text = "";
textPersonCity.Text = "";
textPersonState.Text = "";
textPersonZip.Text = "";

checkPersonActive.Checked = false;
picturePersonPhoto.Image = null;

textPersonPhoneHome.Text = "";
textPersonPhoneWork.Text = "";
textPersonPhoneCell.Text = "";
textPersonPhoneFax.Text = "";
textPersonPhoneOther.Text = "";

comboPersonCompany.SelectedIndex = -1;

EnablePerson(false);
PersonNeedsSaved(false);
buttonPersonDelete.Enabled = false;
}
/*******************************************************************************
Function    : EnablePerson()
Description : 
Parameters  : bool enabled - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
void EnablePerson(bool enabled)
{
textPersonName.Enabled = enabled;
textPersonAddress1.Enabled = enabled;
textPersonAddress2.Enabled = enabled;
textPersonCity.Enabled = enabled;
textPersonState.Enabled = enabled;
textPersonZip.Enabled = enabled;

comboPersonCompany.Enabled = enabled;
checkPersonActive.Enabled = enabled;
picturePersonPhoto.Enabled = enabled;

textPersonPhoneHome.Enabled = enabled;
textPersonPhoneWork.Enabled = enabled;
textPersonPhoneCell.Enabled = enabled;
textPersonPhoneFax.Enabled = enabled;
textPersonPhoneOther.Enabled = enabled;
}
/*******************************************************************************
Function    : GetPersonInfo()
Description : 
Parameters  : stPerson person - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/12 WLM Created
*******************************************************************************/
bool GetPersonInfo(stPerson person)
{
stComboItem ComboItem;

person.Name = textPersonName.Text.Trim();

if (string.IsNullOrEmpty(person.Name))
   {
   MessageBox.Show("Person name must be entered");
   textPersonName.Focus();
   return(false);
   }

person.Address.Address1 = textPersonAddress1.Text.Trim();
person.Address.Address2 = textPersonAddress2.Text.Trim();
person.Address.City = textPersonCity.Text.Trim();
person.Address.State = textPersonState.Text.Trim();
person.Address.ZipCode = textPersonZip.Text.Trim();

person.Active = checkPersonActive.Checked;
person.PhotoImage = picturePersonPhoto.Image;

person.PhoneHome = textPersonPhoneHome.Text.Trim();
person.PhoneWork = textPersonPhoneWork.Text.Trim();
person.PhoneCell = textPersonPhoneCell.Text.Trim();
person.PhoneFax = textPersonPhoneFax.Text.Trim();
person.PhoneOther = textPersonPhoneOther.Text.Trim();

ComboItem = comboPersonCompany.SelectedItem as stComboItem;
if (ComboItem != null)
   person.Company = ComboItem.Tag as stCompany;

return(true);
}
/*******************************************************************************
Function    : buttonPersonUpdate_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/05/12 WLM Created
*******************************************************************************/
private void buttonPersonUpdate_Click(object sender, EventArgs e)
{
stComboItem ComboItem;
stPerson Person;
bool Result;

ComboItem = comboPersonPerson.SelectedItem as stComboItem;
if (ComboItem == null)
   return;

Person = ComboItem.Tag as stPerson;
if (Person == null)
   return;

if (!GetPersonInfo(Person))
   return;


if (UseSELECT)
   Result = UpdatePersonSELECT(Person);

else
   Result = UpdatePersonWI(Person);

if (Result)
   ComboItem.Text = Person.Name;

PersonNeedsSaved(!Result);

if (!Result)
   return;

comboPersonPerson.Items.Remove(ComboItem);
comboPersonPerson.Items.Add(ComboItem);
comboPersonPerson.SelectedItem = ComboItem;
}
/*******************************************************************************
Function    : buttonPersonNew_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/05/12 WLM Created
*******************************************************************************/
private void buttonPersonNew_Click(object sender, EventArgs e)
{
stComboItem ComboItem;
stPerson Person;
bool Result;

Person = new stPerson();

if (!GetPersonInfo(Person))
   return;

if (UseSELECT)
   Result = NewPersonSELECT(Person);

else
   Result = NewPersonWI(Person);

PersonNeedsSaved(!Result);

if (!Result)
   return;

ComboItem = new stComboItem(Person.Name, Person);
comboPersonPerson.Items.Add(ComboItem);
comboPersonPerson.SelectedItem = ComboItem;
}
/*******************************************************************************
Function    : buttonPersonDelete_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/05/12 WLM Created
*******************************************************************************/
private void buttonPersonDelete_Click(object sender, EventArgs e)
{
stComboItem ComboItem;
stPerson Person;
bool Result;
string Str;

ComboItem = comboPersonPerson.SelectedItem as stComboItem;
if (ComboItem == null)
   return;

Person = ComboItem.Tag as stPerson;
if (Person == null)
   return;

Str = string.Format("Delete Person {0}", Person.Name);
if (MessageBox.Show(Str, "", MessageBoxButtons.YesNo) == DialogResult.No)
   return;

if (UseSELECT)
   Result = DeletePersonSELECT(Person);

else
   Result = DeletePersonWI(Person);

PersonNeedsSaved(!Result);

if (!Result)
   return;

ClearPerson();

comboPersonPerson.Items.Remove(ComboItem);
comboPersonPerson.SelectedIndex = -1;
}
/*******************************************************************************
Function    : tsPersonSelect_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/05/12 WLM Created
*******************************************************************************/
private void tsPersonSelect_Click(object sender, EventArgs e)
{
OpenFileDialog OpenDialog;
string Str;

try
{
OpenDialog = new OpenFileDialog();

OpenDialog.Filter
   = "Select Image (*.gif;*.jpg;*.jpe;*.jpeg;*.png;*.bmp;)|*.gif;*.jpg;*.jpe;*.jpeg;*.png;*.bmp;";
OpenDialog.RestoreDirectory = true;

if (OpenDialog.ShowDialog() != DialogResult.OK)
   {
   OpenDialog.Dispose();
   return;
   }

picturePersonPhoto.Image = Image.FromFile(OpenDialog.FileName);
OpenDialog.Dispose();

PersonNeedsSaved(true);
}

catch (Exception ex)
   {
   Str = string.Format("Failed to load image\n{0}", ex.Message);
   MessageBox.Show(Str);
   }
}
/*******************************************************************************
Function    : tsPersonClear_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/05/12 WLM Created
*******************************************************************************/
private void tsPersonClear_Click(object sender, EventArgs e)
{
picturePersonPhoto.Image = null;
PersonNeedsSaved(true);
}
/*******************************************************************************
Function    : tsPersonCopy_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/05/12 WLM Created
*******************************************************************************/
private void tsPersonCopy_Click(object sender, EventArgs e)
{
CutPasteImage = picturePersonPhoto.Image;
}
/*******************************************************************************
Function    : tsPersonPaste_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/05/12 WLM Created
*******************************************************************************/
private void tsPersonPaste_Click(object sender, EventArgs e)
{
picturePersonPhoto.Image = CutPasteImage;
PersonNeedsSaved(true);
}
/*******************************************************************************
Function    : LoadPersonCombo()
Description : 
Parameters  : None
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/12 WLM Created
*******************************************************************************/
bool LoadPersonCombo()
{
bool Result;
stComboItem ComboItem;

comboPersonPerson.Items.Clear();

/* Add <New>'s to ComboBoxes */
ComboItem = new stComboItem(NEW_PERSON, new stPerson(NEW_PERSON));
comboPersonPerson.Items.Add(ComboItem);

if (UseSELECT)
   Result = LoadPersonNamesSELECT();

else
   Result = LoadPersonNamesWI();

return(Result);
}
} /* End Of Class MainForm */
} /* End Of NameSpace WIDatabaseSample */